// Sample code: load images and determine if a person is blinking in the images

// This sample demonstrates how to use the detectBlink function. First, an image is loaded.
// Next, the left and right eye blink scores are computed
// Build on Linux: g++ -o blink_detection --std=c++11 ./blink_detection.cpp -I ../ -L ../trueface_sdk -l tf -fopenmp
// Build on macOS: g++ -o blink_detection --std=c++11 ./blink_detection.cpp -I ../ -L ../trueface_sdk -l tf


#include "tf_sdk.h"
#include <iostream>

int main() {
    Trueface::SDK tfSdk;
    // TODO: Either input your token in the CMakeLists.txt file, or insert it below directly
    bool valid = tfSdk.setLicense(TRUEFACE_TOKEN);

    if (!valid) {
        std::cout << "Error: the provided license is invalid." << std::endl;
        return 1;
    }

    const float blinkThreshold = 0.4;

    // Load the image with the eyes open
    Trueface::ErrorCode errorCode = tfSdk.setImage("../../images/open_eyes.jpg");
    if (errorCode != Trueface::ErrorCode::NO_ERROR) {
        std::cout << "Error: could not load the image" << std::endl;
        return 1;
    }

    std::cout << "Running blink detection with open eye image" << std::endl;

    float leftScore, rightScore;
    errorCode = tfSdk.detectBlink(leftScore, rightScore);
    if (errorCode != Trueface::ErrorCode::NO_ERROR) {
        std::cout << "Error: could not load the image" << std::endl;
        return 1;
    }

    if (leftScore < blinkThreshold && rightScore < blinkThreshold) {
        std::cout << "Both eyes are closed" << std::endl;
    } else if (leftScore >= blinkThreshold && rightScore >= blinkThreshold) {
        std::cout << "Both eyes are open" << std::endl;
    } else {
        std::cout << "One eye is open, one eye is closed" << std::endl;
    }

    std::cout << "Running blink detection with closed eye image" << std::endl;

    // Load the image with the eyes closed
    errorCode = tfSdk.setImage("../../images/closed_eyes.jpg");
    if (errorCode != Trueface::ErrorCode::NO_ERROR) {
        std::cout << "Error: could not load the image" << std::endl;
        return 1;
    }

    errorCode = tfSdk.detectBlink(leftScore, rightScore);
    if (errorCode != Trueface::ErrorCode::NO_ERROR) {
        std::cout << "Error: could not load the image" << std::endl;
        return 1;
    }

    if (leftScore < blinkThreshold && rightScore < blinkThreshold) {
        std::cout << "Both eyes are closed" << std::endl;
    } else if (leftScore >= blinkThreshold && rightScore >= blinkThreshold) {
        std::cout << "Both eyes are open" << std::endl;
    } else {
        std::cout << "One eye is open, one eye is closed" << std::endl;
    }

    return 0;
}